@@ -27,6 +27,7 @@
 #include "nautilus-directory.h"
 #include "nautilus-directory.h"
 #include "nautilus-file-private.h"
+#include "nautilus-file-utilities.h"
 #include "nautilus-global-preferences.h"
 #include "nautilus-metadata.h"
 #include "nautilus-search-uri.h"
@@ -37,13 +38,11 @@
 #include <eel/eel-vfs-extensions.h>
 #include <eel/eel-xml-extensions.h>
 #include <libxml/parser.h>
-#include <libxml/xmlmemory.h>
 #include <gtk/gtkmain.h>
 #include <libgnomevfs/gnome-vfs-file-info.h>
 #include <libgnomevfs/gnome-vfs-types.h>
 #include <libgnomevfs/gnome-vfs-uri.h>
 #include <libgnomevfs/gnome-vfs.h>
-#include <libnautilus/nautilus-bonobo-workarounds.h>
 #include <stdlib.h>
 
 #define METAFILE_XML_VERSION "1.0"
@@ -59,61 +58,6 @@
          | GNOME_VFS_PERM_GROUP_ALL \
 	 | GNOME_VFS_PERM_OTHER_ALL)
 
-static void nautilus_metafile_init       (NautilusMetafile      *metafile);
-static void nautilus_metafile_class_init (NautilusMetafileClass *klass);
-
-static void destroy (GtkObject *metafile);
-
-static CORBA_boolean corba_is_read (PortableServer_Servant  servant,
-				    CORBA_Environment      *ev);
-
-static CORBA_char *corba_get		      (PortableServer_Servant  servant,
-					       const CORBA_char       *file_name,
-					       const CORBA_char       *key,
-					       const CORBA_char       *default_value,
-					       CORBA_Environment      *ev);
-static Nautilus_MetadataList *corba_get_list (PortableServer_Servant  servant,
-					       const CORBA_char      *file_name,
-					       const CORBA_char      *list_key,
-					       const CORBA_char      *list_subkey,
-					       CORBA_Environment     *ev);
-
-static void corba_set      (PortableServer_Servant  servant,
-			    const CORBA_char       *file_name,
-			    const CORBA_char       *key,
-			    const CORBA_char       *default_value,
-			    const CORBA_char       *metadata,
-			    CORBA_Environment      *ev);
-static void corba_set_list (PortableServer_Servant       servant,
-			    const CORBA_char            *file_name,
-			    const CORBA_char            *list_key,
-			    const CORBA_char            *list_subkey,
-			    const Nautilus_MetadataList *list,
-			    CORBA_Environment           *ev);
-					       
-static void corba_copy             (PortableServer_Servant   servant,
-				    const CORBA_char        *source_file_name,
-				    const Nautilus_URI       destination_directory_uri,
-				    const CORBA_char        *destination_file_name,
-				    CORBA_Environment       *ev);
-static void corba_remove           (PortableServer_Servant  servant,
-				    const CORBA_char       *file_name,
-				    CORBA_Environment      *ev);
-static void corba_rename           (PortableServer_Servant  servant,
-				    const CORBA_char       *old_file_name,
-				    const CORBA_char       *new_file_name,
-				    CORBA_Environment      *ev);
-static void corba_rename_directory (PortableServer_Servant  servant,
-				    const CORBA_char       *new_directory_uri,
-				    CORBA_Environment      *ev);
-
-static void corba_register_monitor   (PortableServer_Servant          servant,
-				      const Nautilus_MetafileMonitor  monitor,
-				      CORBA_Environment              *ev);
-static void corba_unregister_monitor (PortableServer_Servant          servant,
-				      const Nautilus_MetafileMonitor  monitor,
-				      CORBA_Environment              *ev);
-
 static char    *get_file_metadata      (NautilusMetafile *metafile,
 					const char       *file_name,
 					const char       *key,
@@ -157,7 +101,9 @@ static void async_read_cancel                (NautilusMetafile *metafile);
 static void nautilus_metafile_set_metafile_contents (NautilusMetafile *metafile,
 					             xmlDocPtr metafile_contents);
 
-NAUTILUS_BONOBO_X_BOILERPLATE (NautilusMetafile, Nautilus_Metafile, BONOBO_X_OBJECT_TYPE, nautilus_metafile)
+BONOBO_CLASS_BOILERPLATE_FULL (NautilusMetafile, nautilus_metafile,
+			       Nautilus_Metafile,
+			       BonoboObject, BONOBO_OBJECT_TYPE)
 
 typedef struct MetafileReadState {
 	gboolean use_public_metafile;
@@ -197,25 +143,7 @@ struct NautilusMetafileDetails {
 static GHashTable *metafiles;
 
 static void
-nautilus_metafile_class_init (NautilusMetafileClass *klass)
-{
-	GTK_OBJECT_CLASS (klass)->destroy = destroy;
-
-	klass->epv.is_read            = corba_is_read;
-	klass->epv.get                = corba_get;
-	klass->epv.get_list           = corba_get_list;
-	klass->epv.set                = corba_set;
-	klass->epv.set_list           = corba_set_list;
-	klass->epv.copy               = corba_copy;
-	klass->epv.remove             = corba_remove;
-	klass->epv.rename             = corba_rename;
-	klass->epv.rename_directory   = corba_rename_directory;
-	klass->epv.register_monitor   = corba_register_monitor;
-	klass->epv.unregister_monitor = corba_unregister_monitor;
-}
-
-static void
-nautilus_metafile_init (NautilusMetafile *metafile)
+nautilus_metafile_instance_init (NautilusMetafile *metafile)
 {
 	metafile->details = g_new0 (NautilusMetafileDetails, 1);
 	
@@ -224,7 +152,7 @@ nautilus_metafile_init (NautilusMetafile *metafile)
 }
 
 static void
-destroy (GtkObject *object)
+finalize (GObject *object)
 {
 	NautilusMetafile  *metafile;
 
@@ -255,7 +183,7 @@ destroy (GtkObject *object)
 
 	g_free (metafile->details);
 
-	EEL_CALL_PARENT (GTK_OBJECT_CLASS, destroy, (object));
+	G_OBJECT_CLASS (parent_class)->finalize (object);
 }
 
 static GnomeVFSURI *
@@ -332,7 +260,7 @@ nautilus_metafile_new (const char *directory_uri)
 {
 	NautilusMetafile *metafile;
 	
-	metafile = NAUTILUS_METAFILE (gtk_object_new (NAUTILUS_TYPE_METAFILE, NULL));
+	metafile = NAUTILUS_METAFILE (g_object_new (NAUTILUS_TYPE_METAFILE, NULL));
 
 	nautilus_metafile_set_directory_uri (metafile, directory_uri);
 
@@ -357,7 +285,7 @@ nautilus_metafile_get (const char *directory_uri)
 	metafile = g_hash_table_lookup (metafiles, canonical_uri);
 	
 	if (metafile != NULL) {
-		bonobo_object_ref (BONOBO_OBJECT (metafile));
+		bonobo_object_ref (metafile);
 	} else {
 		metafile = nautilus_metafile_new (canonical_uri);
 		
@@ -586,7 +514,7 @@ corba_set_list (PortableServer_Servant      servant,
 static void
 corba_copy (PortableServer_Servant   servant,
 	    const CORBA_char        *source_file_name,
-	    const Nautilus_URI       destination_directory_uri,
+	    const CORBA_char        *destination_directory_uri,
 	    const CORBA_char        *destination_file_name,
 	    CORBA_Environment       *ev)
 {
@@ -600,7 +528,7 @@ corba_copy (PortableServer_Servant   servant,
 	copy_file_metadata (source_metafile, source_file_name,
 			    destination_metafile, destination_file_name);
 			    
-	bonobo_object_unref (BONOBO_OBJECT (destination_metafile));
+	bonobo_object_unref (destination_metafile);
 }
 
 static void
@@ -674,7 +602,8 @@ corba_register_monitor (PortableServer_Servant          servant,
 
 	g_return_if_fail (find_monitor_node (metafile->details->monitors, monitor) == NULL);
 
-	metafile->details->monitors = g_list_prepend (metafile->details->monitors, (gpointer) CORBA_Object_duplicate (monitor, ev));	
+	metafile->details->monitors = g_list_prepend (metafile->details->monitors,
+						      (gpointer) CORBA_Object_duplicate (monitor, ev));	
 
 	async_read_start (metafile);
 }
@@ -1595,7 +1524,7 @@ remove_file_metadata (NautilusMetafile *metafile,
 			g_hash_table_remove (hash,
 					     file_name);
 			xmlFree (key);
-			eel_xml_remove_node (file_node);
+			xmlUnlinkNode (file_node);
 			xmlFreeNode (file_node);
 			directory_request_write_metafile (metafile);
 		}
@@ -1683,7 +1612,7 @@ can_use_public_metafile (NautilusMetafile *metafile)
 		return FALSE;
 	}
 
-	preference_value = eel_preferences_get_integer (NAUTILUS_PREFERENCES_USE_PUBLIC_METADATA);
+	preference_value = eel_preferences_get_enum (NAUTILUS_PREFERENCES_USE_PUBLIC_METADATA);
 
 	if (preference_value == NAUTILUS_SPEED_TRADEOFF_ALWAYS) {
 		return TRUE;
@@ -1776,6 +1705,7 @@ metafile_read_check_for_directory (NautilusMetafile *metafile)
 		(&metafile->details->read_state->get_file_info_handle,
 		 &fake_list,
 		 GNOME_VFS_FILE_INFO_FOLLOW_LINKS,
+		 GNOME_VFS_PRIORITY_DEFAULT,
 		 metafile_read_check_for_directory_callback,
 		 metafile);
 }
@@ -1852,7 +1782,7 @@ metafile_read_done_callback (GnomeVFSResult result,
 		return;
 	}
 	
-	/* The gnome-xml parser requires a zero-terminated array. */
+	/* The libxml parser requires a zero-terminated array. */
 	buffer = g_realloc (file_contents, size + 1);
 	buffer[size] = '\0';
 	nautilus_metafile_set_metafile_contents (metafile,
@@ -1874,7 +1804,9 @@ metafile_read_restart (NautilusMetafile *metafile)
 		 GNOME_VFS_URI_HIDE_NONE);
 
 	metafile->details->read_state->handle = eel_read_entire_file_async
-		(text_uri, metafile_read_done_callback, metafile);
+		(text_uri,
+		 GNOME_VFS_PRIORITY_DEFAULT,
+		 metafile_read_done_callback, metafile);
 
 	g_free (text_uri);
 }
@@ -1945,7 +1877,7 @@ metafile_write_done (NautilusMetafile *metafile)
 	xmlFree (metafile->details->write_state->buffer);
 	g_free (metafile->details->write_state);
 	metafile->details->write_state = NULL;
-	bonobo_object_unref (BONOBO_OBJECT (metafile));
+	bonobo_object_unref (metafile);
 }
 
 static void
@@ -2060,6 +1992,7 @@ metafile_write_start (NautilusMetafile *metafile)
 		 ? metafile->details->public_vfs_uri
 		 : metafile->details->private_vfs_uri,
 		 GNOME_VFS_OPEN_WRITE, FALSE, METAFILE_PERMISSIONS,
+		 GNOME_VFS_PRIORITY_DEFAULT,
 		 metafile_write_create_callback, metafile);
 }
 
@@ -2070,11 +2003,11 @@ metafile_write (NautilusMetafile *metafile)
 	
 	g_assert (NAUTILUS_IS_METAFILE (metafile));
 
-	bonobo_object_ref (BONOBO_OBJECT (metafile));
+	bonobo_object_ref (metafile);
 
 	/* If we are already writing, then just remember to do it again. */
 	if (metafile->details->write_state != NULL) {
-		bonobo_object_unref (BONOBO_OBJECT (metafile));
+		bonobo_object_unref (metafile);
 		metafile->details->write_state->write_again = TRUE;
 		return;
 	}
@@ -2084,7 +2017,7 @@ metafile_write (NautilusMetafile *metafile)
 	 * the metafile in this case.
 	 */
 	if (metafile->details->xml == NULL) {
-		bonobo_object_unref (BONOBO_OBJECT (metafile));
+		bonobo_object_unref (metafile);
 		return;
 	}
 
@@ -2109,7 +2042,7 @@ metafile_write_idle_callback (gpointer callback_data)
 	metafile->details->write_idle_id = 0;
 	metafile_write (metafile);
 
-	bonobo_object_unref (BONOBO_OBJECT (metafile));
+	bonobo_object_unref (metafile);
 
 	return FALSE;
 }
@@ -2125,9 +2058,26 @@ directory_request_write_metafile (NautilusMetafile *metafile)
 
 	/* Set up an idle task that will write the metafile. */
 	if (metafile->details->write_idle_id == 0) {
-		bonobo_object_ref (BONOBO_OBJECT (metafile));
+		bonobo_object_ref (metafile);
 		metafile->details->write_idle_id =
-			gtk_idle_add (metafile_write_idle_callback,
-				      metafile);
+			gtk_idle_add (metafile_write_idle_callback, metafile);
 	}
 }
+
+static void
+nautilus_metafile_class_init (NautilusMetafileClass *klass)
+{
+	G_OBJECT_CLASS (klass)->finalize = finalize;
+
+	klass->epv.is_read            = corba_is_read;
+	klass->epv.get                = corba_get;
+	klass->epv.get_list           = corba_get_list;
+	klass->epv.set                = corba_set;
+	klass->epv.set_list           = corba_set_list;
+	klass->epv.copy               = corba_copy;
+	klass->epv.remove             = corba_remove;
+	klass->epv.rename             = corba_rename;
+	klass->epv.rename_directory   = corba_rename_directory;
+	klass->epv.register_monitor   = corba_register_monitor;
+	klass->epv.unregister_monitor = corba_unregister_monitor;
+}
